"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var WatchFileSystem = /** @class */ (function () {
    function WatchFileSystem(compiler, wfs, ignoredFile) {
        this.compiler = compiler;
        this.wfs = wfs;
        this.ignoredFile = ignoredFile;
    }
    WatchFileSystem.prototype.watch = function (files, dirs, missing, startTime, options, callback, callbackUndelayed) {
        var _this = this;
        var notIgnored = function (path) { return path !== _this.ignoredFile; };
        var watcher = this.wfs.watch(files.filter(notIgnored), dirs, missing, startTime, options, function (err, filesModified, dirsModified, missingModified, fileTimestamps, dirTimestamps, removedFiles) {
            if (err) {
                return callback(err);
            }
            // purge ignored file
            _this.compiler.inputFileSystem.purge(_this.ignoredFile);
            // set new timestamp
            fileTimestamps.set(_this.ignoredFile, new Date().getTime());
            callback(err, filesModified, dirsModified, missingModified, fileTimestamps, dirTimestamps, [_this.ignoredFile].concat(removedFiles));
        }, callbackUndelayed);
        return {
            close: function () { return watcher.close(); },
            pause: function () { return watcher.pause(); },
            getContextTimestamps: function () { return watcher.getContextTimestamps(); },
            getFileTimestamps: function () { return watcher.getFileTimestamps(); }
        };
    };
    return WatchFileSystem;
}());
exports.WatchFileSystem = WatchFileSystem;
//# sourceMappingURL=watch-fs.js.map